pronunciation constant
MetadataFlag
const pronunciation
Produced in the tags field of the result object, prefixed by "pron:".
This is the system's best guess for the pronunciation of the word or
phrase. The format of the pronunciation is a space-delimited list of
Arpabet phoneme codes. If you add &ipa=1 to your API query, the
pronunciation string will instead use the International Phonetic Alphabet.
Note that for terms that are very rare or outside of the vocabulary,
the pronunciation will be guessed based on the spelling. In certain cases
the pronunciation may be ambiguous, in which case the system's best guess
is chosen based on the entire query.
Implementation
static const MetadataFlag pronunciation = MetadataFlag._('pronunciation');